<?php

namespace App\Service;

use App\Entity\Commentaire;
use App\Entity\Film;
use App\Entity\MediaVideo;
use Doctrine\Bundle\DoctrineBundle\Attribute\AsDoctrineListener;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Event\PostPersistEventArgs;
use Doctrine\ORM\Events;
use Symfony\Component\Config\Definition\Exception\Exception;

#[AsDoctrineListener(event: Events::postPersist)]
class FilmCreationListener
{
    public function __construct(
        protected Mattermost $mattermostSender,
        protected EntityManagerInterface $em
    )
    {
    }

    public function postPersist(PostPersistEventArgs $args): void
    {
        $entity = $args->getObject();
        if (
            !$entity instanceof Film &&
            !$entity instanceof Commentaire &&
            !$entity instanceof MediaVideo
        )
        {
            return;
        }

        try {
            if ($entity instanceof Film)
                $this->mattermostSender->sendNouveauFilm($entity);
            elseif ($entity instanceof MediaVideo) {
                $this->mattermostSender->sendNewMediaVideo($entity->getFilm());
            } else {
                $this->mattermostSender->sendNouveauCommentaire($entity->getUser(), $entity->getFilm());
                
                if ($entity->getFilm()->getUsersWantToView()->contains($entity->getUser())) {
                    $entity->getFilm()->removeUserWantToView($entity->getUser());
                }
                if (!$entity->getFilm()->getUsersWhoSeen()->contains($entity->getUser())) {
                    $entity->getFilm()->addUserWhoSeen($entity->getUser());
                }


                $this->em->flush();
            }
        } catch (Exception $exception) {

        }
    }
}